==> trircd-release-5.1.7-r.tar.gz: trircd-release-5.1.7-r/modules/m_post.c <==
/************************************************************************
 *   IRC - Internet Relay Chat, modules/m_post.c
 *
 *   Copyright (C) 2000-2002 TR-IRCD Development
 *
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Co Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include "h.h"

static struct Message _msgtab[] = {
    {MSG_POST, 0, MAXPARA, M_SLOW, 0L,
     m_post, m_post, m_ignore, m_ignore, m_ignore}
};

#ifndef STATIC_MODULES

char *_version = "$Revision: 5.5 $";

void _modinit(void)
{
    mod_add_cmd(_msgtab);
}

void _moddeinit(void)
{
    mod_del_cmd(_msgtab);
}
#else
void m_post_init(void)
{
    mod_add_cmd(_msgtab);
}
#endif

/*
** m_post
**      parv[0] = sender prefix
**      parv[1] = comment
*/
int m_post(aClient *cptr, aClient *sptr, int parc, char *parv[]) {

    sendto_lev(REJ_LEV, "Client rejected for POST command: [%s]",
                        cptr->sockhost);
    return exit_client(sptr, sptr, "Client Exit");
}

==> trircd-release-5.7.3-r.tar.gz: trircd-release-5.7.3-r/modules/m_post.c <==
/************************************************************************
 *   IRC - Internet Relay Chat, modules/m_post.c
 *
 *   Copyright (C) 2000-2003 TR-IRCD Development
 *
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Co Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include "h.h"

static struct Message a_msgtab[] = {
    {MSG_HTTPPOST, 0, MAXPARA, M_SLOW, 0L,
     m_post, m_post, m_ignore, m_ignore, m_ignore}
};

static struct Message b_msgtab[] = {
    {MSG_HTTPPUT, 0, MAXPARA, M_SLOW, 0L,
     m_post, m_post, m_ignore, m_ignore, m_ignore}
};

static struct Message c_msgtab[] = {
    {MSG_HTTPGET, 0, MAXPARA, M_SLOW, 0L,
     m_post, m_post, m_ignore, m_ignore, m_ignore}
};


#ifndef STATIC_MODULES

char *_version = "$Revision: 1.3 $";

void _modinit(void)
{
    mod_add_cmd(a_msgtab);
    mod_add_cmd(b_msgtab);
    mod_add_cmd(c_msgtab);
}

void _moddeinit(void)
{
    mod_del_cmd(a_msgtab);
    mod_del_cmd(b_msgtab);
    mod_del_cmd(c_msgtab);
}
#else
void m_post_init(void)
{
    mod_add_cmd(a_msgtab);
    mod_add_cmd(b_msgtab);
    mod_add_cmd(c_msgtab);
}
#endif

/*
** m_post
**      parv[0] = sender prefix
**      parv[1] = comment
*/
int m_post(aClient *cptr, aClient *sptr, int parc, char *parv[]) {

    sendto_lev(REJ_LEV, "Client rejected for POST command: [%s]",
                        sptr->sockhost);
    return exit_client(sptr, sptr, "Client Exit");
}
